# AOI-API
AOI_API


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.1
- Package version: 1.0.1
- Build package: org.openapitools.codegen.languages.PythonLegacyClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import AOI_API
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import AOI_API
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import AOI_API
from AOI_API.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost/AOIServer
# See configuration.py for a list of all supported configuration parameters.
configuration = AOI_API.Configuration(
    host = "http://localhost/AOIServer"
)



# Enter a context with an instance of the API client
with AOI_API.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = AOI_API.AOIApi(api_client)
    board_width = 3.4 # float | width of board to be scanned (optional)
board_length = 3.4 # float | length of board to be scanned (optional)
step_size = 3.4 # float | step size between images (optional)

    try:
        # 
        api_instance.post_scan_board(board_width=board_width, board_length=board_length, step_size=step_size)
    except ApiException as e:
        print("Exception when calling AOIApi->post_scan_board: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/AOIServer*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AOIApi* | [**post_scan_board**](docs/AOIApi.md#post_scan_board) | **POST** /scan_board | 
*AOIApi* | [**put_calibration**](docs/AOIApi.md#put_calibration) | **PUT** /calibrate | 


## Documentation For Models

 - [DbPhrameJSONStore](docs/DbPhrameJSONStore.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

corey.sadler@3adesign.co.uk


